/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

"use strict";

function createRootMessageHandler(sessionId) {
  const { MessageHandlerRegistry } = ChromeUtils.import(
    "chrome://remote/content/shared/messagehandler/MessageHandlerRegistry.jsm"
  );
  const { RootMessageHandler } = ChromeUtils.import(
    "chrome://remote/content/shared/messagehandler/RootMessageHandler.jsm"
  );
  return MessageHandlerRegistry.getOrCreateMessageHandler(
    sessionId,
    RootMessageHandler.type
  );
}

/**
 * Load the provided url in an existing browser.
 * Returns a promise which will resolve when the page is loaded.
 *
 * @param {Browser} browser
 *     The browser element where the URL should be loaded.
 * @param {String} url
 *     The URL to load in the new tab
 */
async function loadURL(browser, url) {
  const loaded = BrowserTestUtils.browserLoaded(browser);
  BrowserTestUtils.loadURI(browser, url);
  return loaded;
}

/**
 * Create a new foreground tab loading the provided url.
 * Returns a promise which will resolve when the page is loaded.
 *
 * @param {String} url
 *     The URL to load in the new tab
 */
async function addTab(url) {
  const tab = await BrowserTestUtils.openNewForegroundTab(gBrowser, url);
  registerCleanupFunction(() => {
    gBrowser.removeTab(tab);
  });
  return tab;
}
